@@ -508,11 +508,12 @@ class Galaxy:
 
         return filter_dict
 
-    def __init__(self, hostname, geom, mapping=None, file_name=""):
+    def __init__(self, hostname, geom, mapping=None, file_name="", access_token=None):
         self.hostname = hostname
         self.geom = geom
         self.mapping = mapping
         self.file_name = file_name
+        self.access_token = access_token
 
     def fetch(self, output_format, is_hdx_export=False, all_feature_filter_json=None):
         if all_feature_filter_json:
@@ -614,10 +615,13 @@ class Galaxy:
                                     },
                                 }
                         # sending post request and saving response as response object
+
                         headers = {
                             "accept": "application/json",
                             "Content-Type": "application/json",
                         }
+                        if self.access_token:
+                            headers["access_token"] = self.access_token
                         # print(request_body)
                         try:
                             if all_feature_filter_json:
@@ -800,6 +804,8 @@ class Galaxy:
             }
 
         headers = {"accept": "application/json", "Content-Type": "application/json"}
+        if self.access_token:
+            headers["access_token"] = self.access_token
         # print(request_body)
         try:
             with requests.Session() as req_session:
